about summary refs log tree commit diff
diff options
context:
space:
mode:
authorAndrea Ciliberti <meziu210@icloud.com>2022-08-07 19:30:05 +0200
committerAndrea Ciliberti <meziu210@icloud.com>2022-08-07 19:30:05 +0200
commit926f58745eca4995c16ced841074055bfbae58cf (patch)
treef7dd7f09c37afd61aa3e7a3481297219903c1b3b
parent5a9c3a2daa1cc2fa19adfbe5b3c61ba20ff6fb56 (diff)
downloadrust-926f58745eca4995c16ced841074055bfbae58cf.tar.gz
rust-926f58745eca4995c16ced841074055bfbae58cf.zip
Fix HorizonOS regression in FileTimes
-rw-r--r--library/std/src/sys/unix/fs.rs10
1 files changed, 5 insertions, 5 deletions
diff --git a/library/std/src/sys/unix/fs.rs b/library/std/src/sys/unix/fs.rs
index b5cc8038ca4..e0c74a5be56 100644
--- a/library/std/src/sys/unix/fs.rs
+++ b/library/std/src/sys/unix/fs.rs
@@ -544,11 +544,11 @@ impl Default for FileTimes {
     fn default() -> Self {
         // Redox doesn't appear to support `UTIME_OMIT`, so we stub it out here, and always return
         // an error in `set_times`.
         // ESP-IDF does not support `futimens` at all and the behavior for that OS is therefore
         // the same as for Redox.
-        #[cfg(any(target_os = "redox", target_os = "espidf"))]
+        #[cfg(any(target_os = "redox", target_os = "espidf", target_os = "horizon"))]
         let omit = libc::timespec { tv_sec: 0, tv_nsec: 0 };
-        #[cfg(not(any(target_os = "redox", target_os = "espidf")))]
+        #[cfg(not(any(target_os = "redox", target_os = "espidf", target_os = "horizon")))]
         let omit = libc::timespec { tv_sec: 0, tv_nsec: libc::UTIME_OMIT as _ };
         Self([omit; 2])
     }
@@ -1079,9 +1079,9 @@ impl File {
 
     pub fn set_times(&self, times: FileTimes) -> io::Result<()> {
         cfg_if::cfg_if! {
-            if #[cfg(any(target_os = "redox", target_os = "espidf"))] {
+            if #[cfg(any(target_os = "redox", target_os = "espidf", target_os = "horizon"))] {
                 // Redox doesn't appear to support `UTIME_OMIT`.
                 // ESP-IDF does not support `futimens` at all and the behavior for that OS is therefore
                 // the same as for Redox.
                 drop(times);
                 Err(io::const_io_error!(
@@ -544,11 +544,11 @@ impl Default for FileTimes {
         // Redox doesn't appear to support `UTIME_OMIT`, so we stub it out here, and always return
         // an error in `set_times`.
-        // ESP-IDF does not support `futimens` at all and the behavior for that OS is therefore
+        // ESP-IDF and HorizonOS do not support `futimens` at all and the behavior for those OS is therefore
         // the same as for Redox.
@@ -1079,9 +1079,9 @@ impl File {
                 // Redox doesn't appear to support `UTIME_OMIT`.
-                // ESP-IDF does not support `futimens` at all and the behavior for that OS is therefore
+                // ESP-IDF and HorizonOS do not support `futimens` at all and the behavior for those OS is therefore
                 // the same as for Redox.
                 drop(times);